@@ -26,10 +26,15 @@ def login_to_google(username, password):
     br.form['Email'] = username
     br.form['Passwd'] = password
     raw = br.submit().read()
-    if b'<title>Account overview - Account Settings</title>' not in raw:
+    if re.search(br'<title>.*?Account Settings</title>', raw) is None:
+        x = re.search(br'(?is)<title>.*?</title>', raw)
+        if x is not None:
+            print ('Title of post login page: %s'%x.group())
+        #open('/tmp/goog.html', 'wb').write(raw)
         raise ValueError(('Failed to login to google with credentials: %s %s'
             '\nGoogle sometimes requires verification when logging in from a '
-            'new IP address. Use lynx to login and supply the verification.')
+            'new IP address. Use lynx to login and supply the verification, '
+            'at: lynx -accept_all_cookies https://accounts.google.com/ServiceLogin?service=code')
                 %(username, password))
     return br
 
@@ -344,6 +349,9 @@ class GoogleCode(Base):# {{{
 
 class SourceForge(Base): # {{{
 
+    # Note that you should manually ssh once to username,project@frs.sourceforge.net
+    # on the staging server so that the host key is setup
+
     def __init__(self, files, project, version, username, replace=False):
         self.username, self.project, self.version = username, project, version
         self.base = '/home/frs/project/c/ca/'+project
