@@ -246,14 +246,15 @@ class DevicePlugin(Plugin):
         the user.
 
         :param connected_device: The device that we are trying to open. It is
-        a tuple of (vendor id, product id, bcd, manufacturer name, product
-        name, device serial number). However, some device have no serial number
-        and on windows only the first three fields are present, the rest are
-        None.
+            a tuple of (vendor id, product id, bcd, manufacturer name, product
+            name, device serial number). However, some devices have no serial
+            number and on windows only the first three fields are present, the
+            rest are None.
 
         :param library_uuid: The UUID of the current calibre library. Can be
-        None if there is no library (for example when used from the command
-        line.
+            None if there is no library (for example when used from the command
+            line).
+
         '''
         raise NotImplementedError()
 
