@@ -425,15 +425,24 @@ class DirContainer(object):
                     self.opfname = path
                     return
 
+    def _unquote(self, path):
+        # urlunquote must run on a bytestring and will return a bytestring
+        # If it runs on a unicode object, it returns a double encoded unicode
+        # string: unquote(u'%C3%A4') != unquote(b'%C3%A4').decode('utf-8')
+        # and the latter is correct
+        if isinstance(path, unicode):
+            path = path.encode('utf-8')
+        return urlunquote(path).decode('utf-8')
+
     def read(self, path):
         if path is None:
             path = self.opfname
-        path = os.path.join(self.rootdir, path)
-        with open(urlunquote(path), 'rb') as f:
+        path = os.path.join(self.rootdir, self._unquote(path))
+        with open(path, 'rb') as f:
             return f.read()
 
     def write(self, path, data):
-        path = os.path.join(self.rootdir, urlunquote(path))
+        path = os.path.join(self.rootdir, self._unquote(path))
         dir = os.path.dirname(path)
         if not os.path.isdir(dir):
             os.makedirs(dir)
@@ -442,7 +451,7 @@ class DirContainer(object):
 
     def exists(self, path):
         try:
-            path = os.path.join(self.rootdir, urlunquote(path))
+            path = os.path.join(self.rootdir, self._unquote(path))
         except ValueError: #Happens if path contains quoted special chars
             return False
         return os.path.isfile(path)
@@ -942,12 +951,12 @@ class Manifest(object):
             if isinstance(data, etree._Element):
                 ans = xml2str(data, pretty_print=self.oeb.pretty_print)
                 if self.media_type in OEB_DOCS:
-                    # Convert self closing div|span|a tags to normally closed
-                    # ones, as they are interpreted incorrectly by some browser
-                    # based renderers
+                    # Convert self closing div|span|a|video|audio|iframe tags
+                    # to normally closed ones, as they are interpreted
+                    # incorrectly by some browser based renderers
                     ans = re.sub(
                         # tag name followed by either a space or a /
-                        r'<(?P<tag>div|a|span)(?=[\s/])(?P<arg>[^>]*)/>',
+                        r'<(?P<tag>div|a|span|video|audio|iframe)(?=[\s/])(?P<arg>[^>]*)/>',
                         r'<\g<tag>\g<arg>></\g<tag>>', ans)
                 return ans
             if isinstance(data, unicode):
@@ -1068,6 +1077,12 @@ class Manifest(object):
         if item in self.oeb.spine:
             self.oeb.spine.remove(item)
 
+    def remove_duplicate_item(self, item):
+        if item in self.ids:
+            item = self.ids[item]
+        del self.ids[item.id]
+        self.items.remove(item)
+
     def generate(self, id=None, href=None):
         """Generate a new unique identifier and/or internal path for use in
         creating a new manifest item, using the provided :param:`id` and/or
