@@ -214,6 +214,9 @@ class SchedulerDialog(QDialog, Ui_Dialog):
 
         self.recipes.setModel(self.recipe_model)
         self.detail_box.setVisible(False)
+        self.download_button = self.buttonBox.addButton(_('&Download now'),
+                self.buttonBox.ActionRole)
+        self.download_button.setIcon(QIcon(I('arrow-down.png')))
         self.download_button.setVisible(False)
         self.recipes.currentChanged = self.current_changed
         for b, c in self.SCHEDULE_TYPES.iteritems():
@@ -371,7 +374,8 @@ class SchedulerDialog(QDialog, Ui_Dialog):
         '''%dict(title=recipe.get('title'), cb=_('Created by: '),
             author=recipe.get('author', _('Unknown')),
             description=recipe.get('description', '')))
-
+        self.download_button.setToolTip(
+                _('Download %s now')%recipe.get('title'))
         scheduled = schedule_info is not None
         self.schedule.setChecked(scheduled)
         self.toggle_schedule_info()
@@ -458,7 +462,7 @@ class Scheduler(QObject):
             delta = timedelta(days=self.oldest)
             try:
                 ids = list(self.db.tags_older_than(_('News'),
-                    delta))
+                    delta, must_have_authors=['calibre']))
             except:
                 # Happens if library is being switched
                 ids = []
