@@ -22,6 +22,7 @@ from calibre.utils.icu import sort_key
 from calibre.utils.search_query_parser import SearchQueryParser
 from calibre.library.caches import (_match, CONTAINS_MATCH, EQUALS_MATCH,
     REGEXP_MATCH, MetadataBackup, force_to_bool)
+from calibre.library.save_to_disk import find_plugboard
 from calibre import strftime, isbytestring
 from calibre.constants import filesystem_encoding, DEBUG
 from calibre.gui2.library import DEFAULT_SORT
@@ -429,7 +430,8 @@ class BooksModel(QAbstractTableModel): # {{{
 
     def get_preferred_formats_from_ids(self, ids, formats,
                               set_metadata=False, specific_format=None,
-                              exclude_auto=False, mode='r+b'):
+                              exclude_auto=False, mode='r+b',
+                              use_plugboard=None, plugboard_formats=None):
         from calibre.ebooks.metadata.meta import set_metadata as _set_metadata
         ans = []
         need_auto = []
@@ -453,9 +455,21 @@ class BooksModel(QAbstractTableModel): # {{{
                 pt.seek(0)
                 if set_metadata:
                     try:
-                        _set_metadata(pt, self.db.get_metadata(
-                            id, get_cover=True, index_is_id=True,
-                            cover_as_data=True), format)
+                        mi = self.db.get_metadata(id, get_cover=True,
+                                                  index_is_id=True,
+                                                  cover_as_data=True)
+                        newmi = None
+                        if use_plugboard and format.lower() in plugboard_formats:
+                            plugboards = self.db.prefs.get('plugboards', {})
+                            cpb = find_plugboard(use_plugboard, format.lower(),
+                                                 plugboards)
+                            if cpb:
+                                newmi = mi.deepcopy_metadata()
+                                newmi.template_to_attribute(mi, cpb)
+                        if newmi is not None:
+                            _set_metadata(pt, newmi, format)
+                        else:
+                            _set_metadata(pt, mi, format)
                     except:
                         traceback.print_exc()
                 pt.close()
