@@ -64,8 +64,17 @@ def do_list(db, fields, afields, sort_by, ascending, search_text, line_width, se
     data = db.get_data_as_dict(prefix, authors_as_string=True)
     fields = ['id'] + fields
     title_fields = fields
-    fields = [db.custom_column_label_map[x[1:]]['num'] if x[0]=='*'
-            else x for x in fields]
+    def field_name(f):
+        ans = f
+        if f[0] == '*':
+            if f.endswith('_index'):
+                fkey = f[1:-len('_index')]
+                num = db.custom_column_label_map[fkey]['num']
+                ans = '%d_index'%num
+            else:
+                ans = db.custom_column_label_map[f[1:]]['num']
+        return ans
+    fields = list(map(field_name, fields))
 
     for f in data:
         fmts = [x for x in f['formats'] if x is not None]
@@ -121,8 +130,10 @@ def do_list(db, fields, afields, sort_by, ascending, search_text, line_width, se
 def list_option_parser(db=None):
     fields = set(FIELDS)
     if db is not None:
-        for f in db.custom_column_label_map:
+        for f, data in db.custom_column_label_map.iteritems():
             fields.add('*'+f)
+            if data['datatype'] == 'series':
+                fields.add('*'+f+'_index')
 
     parser = get_parser(_(
 '''\
@@ -161,8 +172,10 @@ def command_list(args, dbpath):
     opts, args = parser.parse_args(sys.argv[:1] + args)
     afields = set(FIELDS)
     if db is not None:
-        for f in db.custom_column_label_map:
+        for f, data in db.custom_column_label_map.iteritems():
             afields.add('*'+f)
+            if data['datatype'] == 'series':
+                afields.add('*'+f+'_index')
     fields = [str(f.strip().lower()) for f in opts.fields.split(',')]
     if 'all' in fields:
         fields = sorted(list(afields))
